Module and Class Hierarchies

[show private | hide private]
[frames | no frames]

## Module Hierarchy

- `spoon`
  - `messaging`
    - `decorators`
    - `messaging`
  - `NullLogger`
  - `ber`: The low level BER based encoding used by spoon to serialize objects.
    - `common`
    - `stream`
    - `tag`
  - `objTypes`
  - `routing`
    - `MeshRouter`: Mesh Routing, this is the protocol by which an ad-hoc network of nodes can be created and how messages may be passed between them.
  - `spoon`
  - `spoonstream`
  - `transports`
    - `SpoonTransport`
    - `transports`

## Class Hierarchy

- `__builtin__.object`: The most base type
  - `spoon.NullLogger.NullLogger`: Dummy logging object.
  - `None.Serial`
    - `spoon.transports.transports.SpoonRPCHello`: This object is sent as a very simple form of initial negotiation.
  - `__builtin__.type`: type(object) -> the object's type type(name, bases, dict) -> a new type
    - `None.SerialMeta`
  - `threading._Verbose`
    - `threading.Thread`
      - `spoon.transports.SpoonTransport.SpoonTransportThread`
  - `spoon.transports.transports.LinkMessage`: Link message is the wrapper which will contain messages sent between two directly connected nodes.
  - `spoon.routing.MeshRouter.MeshRouter`: This class handles LMTYPE_NETWORK messages and LMTYPE_NETWORK_PROTO messages.
  - `spoon.messaging.messaging.Messaging`: This is the main messaging class that implements the basic functionality for Spoon.
    - `spoon.messaging.messaging.SingletonMessaging`: For convinience this is a singleton version of the Messaging system.
  - `spoon.messaging.decorators.receive`: The receive decorator can be used to decorate functions and static methods (NOT methods of class instances) that should receive messages of a given type.
  - `spoon.spoonstream.SocketFile`: Simple wrapper around a socket like object that pretends to be a file.
  - `spoon.spoonstream.SpoonStream`: SpoonStream implements an object stream.
  - `spoon.transports.SpoonTransport.SpoonTransport`: The spoon transport base class.
  - `spoon.spoon.StringIOWrap`: Stupid wrapper around StringIO because it isn't a new style class.
  - `spoon.ber.tag.Tag`: Representation of the header of an ASN.1 object.
- `exceptions.Exception`: Common base class for all exceptions.
  - `spoon.ber.common.BERException`
  - `spoon.routing.MeshRouter.RoutingProtocolError`
    - `spoon.routing.MeshRouter.NodeUnreachable`: Raised when trying to send to a node that is not currently reachable.
  - `spoon.transports.transports.TransportException`

Generated by Epydoc 2.1 on Sun Nov 26 15:33:58 2006 | http://epydoc.sf.net